code cleanup - remove unused hipstream from the RocDecoder class (#155)

このコミットが含まれているのは:
Aryan Salmanpour
2024-01-08 14:54:28 -05:00
committed by GitHub
コミット 224e98ab2d
2個のファイルの変更1行の追加11行の削除
+1 -10
ファイルの表示
@@ -25,15 +25,7 @@ THE SOFTWARE.
RocDecoder::RocDecoder(RocDecoderCreateInfo& decoder_create_info): va_video_decoder_{decoder_create_info}, decoder_create_info_{decoder_create_info} {}
RocDecoder::~RocDecoder() {
hipError_t hipStatus = hipSuccess;
if (hip_stream_) {
hipStatus = hipStreamDestroy(hip_stream_);
if (hipStatus != hipSuccess) {
ERR("ERROR: hipStreamDestroy failed! with hipStatus# " + TOSTR(hipStatus));
}
}
}
RocDecoder::~RocDecoder() {}
rocDecStatus RocDecoder::InitializeDecoder() {
rocDecStatus rocdec_status = ROCDEC_SUCCESS;
@@ -149,7 +141,6 @@ rocDecStatus RocDecoder::InitHIP(int device_id) {
}
CHECK_HIP(hipSetDevice(device_id));
CHECK_HIP(hipGetDeviceProperties(&hip_dev_prop_, device_id));
CHECK_HIP(hipStreamCreate(&hip_stream_));
return ROCDEC_SUCCESS;
}
-1
ファイルの表示
@@ -59,6 +59,5 @@ private:
RocDecoderCreateInfo decoder_create_info_;
VaapiVideoDecoder va_video_decoder_;
hipDeviceProp_t hip_dev_prop_;
hipStream_t hip_stream_;
std::vector<hipExternalMemory_t> hip_ext_mem_;
};